# -*- coding: utf-8 -*-

# Copyright 2016 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json


class AlertsInterface(object):

    def __init__(self, user_token, rest_client):
        self.token = user_token
        self.rest_client = rest_client

    def createAlert(
            self, alert_name, username, alerts_type, alert_expression,
            alert_severity, metric_name, emails, status, notify_period
    ):

        """Creates a new alert, returns status code of creation
        and alert parameters

        :param alert_name: Name of the alert
        :param username: User the alert belongs to
        :param alerts_type: "metric" or "log"
        :param alert_expression: expression to evaluate the alert
        (eg. "cpu.value > 20")
        :param alert_severity: severity level of the alert
        :param metric_name: metric associated with the alert
        :param emails: emails to receive notification when the alert triggers
        :param status: if the alert is active or disable
        :param notify_period: frequency of notifications

        :rtype: array
        """

        data = {
            'alert_name': alert_name,
            'username': username,
            'token': self.token,
            'alerts_type': alerts_type,
            'alert_expression': alert_expression,
            'alert_severity': alert_severity,
            'metric_name': metric_name,
            'emails': emails,
            'status': status,
            'notify_period': notify_period
        }
        path = '/alerts/' + self.token
        header = {'content-type': 'application/json'}

        return self.rest_client.sendPostRequest(path, json.dumps(data), header)

    def getAlerts(self):

        """Return all alerts

        :rtype: array
        """
        path = '/alerts/' + self.token
        return self.rest_client.sendGetRequest(path)

    def modifyAlert(
            self, alert_id, alert_name, username, alerts_type,
            alert_expression, alert_severity, metric_name, emails, status,
            notify_period
    ):

        """Modifies an existing alert with new data

        :param alert_id: Id of the alert to be modified
        :param alert_name: Name of the alert
        :param username: User the alert belongs to
        :param alerts_type: "metric" or "log"
        :param alert_expression: expression to evaluate the alert
        (eg. "cpu.value > 20")
        :param alert_severity: severity level of the alert
        :param metric_name: metric associated with the alert
        :param emails: emails to receive notification when the alert triggers
        :param status: if the alert is active or disable
        :param notify_period: frequency of notifications

        :rtype: array
        """

        data = {
            'alert_name': alert_name,
            'username': username,
            'token': self.token,
            'alerts_type': alerts_type,
            'alert_expression': alert_expression,
            'alert_severity': alert_severity,
            'metric_name': metric_name,
            'emails': emails,
            'status': status,
            'notify_period': notify_period
        }
        path = '/alerts/' + self.token + '/' + str(alert_id)
        header = {'content-type': 'application/json'}

        return self.rest_client.sendPutRequest(path, json.dumps(data), header)

    def getAlert(self, alert_id):

        """Return an specific alert information

        :param alert_id: Id of the alert to be returned

        :rtype: array
        """
        path = '/alerts/' + self.token + '/' + str(alert_id)
        return self.rest_client.sendGetRequest(path)

    def deleteAlert(self, alert_id):
        """Delete an specific alert

        :param alert_id: Id of the alert to be deleted

        :rtype: array
        """
        path = '/alerts/' + self.token + '/' + str(alert_id)
        return self.rest_client.sendDeleteRequest(path)

    def enableAlerts(self, alert_id_list):

        """Bulk enable alerts

        :param alert_id_list: List of ids of the alerts to be enabled

        :rtype: array
        """
        data = {
            'id': alert_id_list
        }
        path = '/alerts/' + self.token + '/enable'
        header = {'content-type': 'application/json'}

        return self.rest_client.sendPostRequest(path, json.dumps(data), header)

    def disableAlerts(self, alert_id_list):

        """Bulk disable alerts

        :param alert_id_list: List of ids of the alerts to be disabled

        :rtype: array
        """

        data = {
            'id': alert_id_list
        }
        path = '/alerts/' + self.token + '/disable'
        header = {'content-type': 'application/json'}

        return self.rest_client.sendPostRequest(path, json.dumps(data), header)



# -*- coding: utf-8 -*-

# Copyright 2016 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
from utils import validateLogName, validateDates


class LogsInterface(object):

    def __init__(self, user_token, rest_client):
        self.token = user_token
        self.rest_client = rest_client

    def sendLog(self, log_name, logs):
        """Return ``dict`` saying how many *logs* were successfully inserted
        with *log_name*.

        :param string log_name: String with the name of the log.
        :param dict logs: ``array`` of ``dict`` containing the logs to send.
        :rtype: dict

        """
        validateLogName(log_name)
        data = {'logs': json.dumps(logs)}
        return self.rest_client.sendPostRequest('/logs/' + self.token +
                                                '/' + log_name + '/', data)

    def getLog(self,
               log_name,
               attribute_name=None,
               pattern=None,
               from_date=None,
               to_date=None,
               offset=None,
               limit=None):
        """Return ``array`` of ``dict`` with the logs that match the params.

        :param string log_name: Name of the log.
        :param string attribute_name: Name of field to be searched. If omitted,
        search all fields.
        :param string pattern: Pattern to match the logs against.
        :param string from_date: Unix formatted start date.
        :param string to_date: Unix formatted end date.
        :param string offset: Result offset.
        :param string limit: Max number of results in the return.
        :rtype: array

        """
        validateDates(from_date, to_date)
        data = {"log_name": log_name}
        if attribute_name:
            data['attribute_name'] = attribute_name
        if pattern:
            data['pattern'] = pattern
        if from_date:
            data['from'] = from_date
        if to_date:
            data['to'] = to_date
        if offset:
            data['offset'] = offset
        if limit:
            data['limit'] = limit

        return self.rest_client.sendGetRequest('/logs/' + self.token + '/',
                                               data)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
test_zeus_client
----------------------------------

Tests for `zeus` module.
"""

import json
import mock
import unittest
from zeus.interfaces.utils import validateDates, ZeusException

from zeus import client

FAKE_TOKEN = 'ZeUsRoCkS'
FAKE_SERVER = 'https://zeus.rocks'


class TestZeusClient(unittest.TestCase):

    def setUp(self):
        # Setting up a Zeus client with a fake token:
        self.z = client.ZeusClient(FAKE_TOKEN, FAKE_SERVER)

    def test_initialization_no_https(self):
        z = client.ZeusClient(FAKE_TOKEN, "zeus.rocks")
        assert z.server == "https://zeus.rocks"
        z = client.ZeusClient(FAKE_TOKEN, "http://zeus.rocks")
        assert z.server == "https://zeus.rocks"

    def test_validate_dates(self):
        # normal
        from_date = 12345
        to_date = 12346
        validateDates(from_date, to_date)
        # None value
        from_date = None
        to_date = 12346
        validateDates(from_date, to_date)
        # invalid value
        from_date = 'wrongvalue'
        to_date = 12346
        self.assertRaises(
            ZeusException, validateDates, from_date, to_date)
        # inversed order
        from_date = 12346
        to_date = 12345
        self.assertRaises(
            ZeusException, validateDates, from_date, to_date)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_empty_log(self, mock_requests):
        logs = []
        self.z.sendLog('ZeusTest', logs)
        mock_requests.post.assert_called_with(FAKE_SERVER + '/logs/' +
                                              FAKE_TOKEN + '/ZeusTest/',
                                              data={"logs": json.dumps(logs)},
                                              headers=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_single_log(self, mock_requests):
        logs = [{"timestamp": 123541423, "key": "TestLog", "key2": 123}]
        self.z.sendLog('ZeusTest', logs)
        mock_requests.post.assert_called_with(FAKE_SERVER + '/logs/' +
                                              FAKE_TOKEN + '/ZeusTest/',
                                              data={"logs": json.dumps(logs)},
                                              headers=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_single_log_wrong_name(self, mock_requests):
        logs = [{"message": "TestLog", "value": 23}]
        self.assertRaises(
            ZeusException, self.z.sendLog, 'W.rongName', logs)
        self.assertRaises(
            ZeusException, self.z.sendLog, '_WrongName', logs)
        self.assertRaises(
            ZeusException, self.z.sendLog, 'W#?rongName', logs)
        self.assertRaises(
            ZeusException, self.z.sendLog, 'W-rongName', logs)
        self.assertRaises(
            ZeusException, self.z.sendLog, None, logs)
        self.assertRaises(
            ZeusException, self.z.sendLog, '', logs)
        self.assertRaises(
            ZeusException, self.z.sendLog, '0123456789ABCDEF' * 16,
            logs)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_multiple_logs(self, mock_requests):
        logs = [{"timestamp": 123541423, "message": "TestLog"},
                {"timestamp": 123541424, "message": "TestLog2"},
                {"timestamp": 123541425, "message": "TestLog3"}, ]
        self.z.sendLog('ZeusTest', logs)
        mock_requests.post.assert_called_with(FAKE_SERVER + '/logs/' +
                                              FAKE_TOKEN + '/ZeusTest/',
                                              data={"logs": json.dumps(logs)},
                                              headers=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_logs(self, mock_requests):
        self.z.getLog('ZeusTest',
                      attribute_name='message',
                      pattern='*',
                      from_date=123456789,
                      to_date=126235344235,
                      offset=23,
                      limit=10)
        mock_requests.get.assert_called_with(FAKE_SERVER + '/logs/' +
                                             FAKE_TOKEN + '/',
                                             params={'log_name': 'ZeusTest',
                                                     'attribute_name':
                                                     'message',
                                                     'pattern': '*',
                                                     'from': 123456789,
                                                     'to': 126235344235,
                                                     'offset': 23,
                                                     'limit': 10})

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_empty_metric(self, mock_requests):
        metrics = []
        self.z.sendMetric('ZeusTest', metrics)
        mock_requests.post.assert_called_with(FAKE_SERVER + '/metrics/' +
                                              FAKE_TOKEN + '/ZeusTest/',
                                              data={"metrics":
                                                    json.dumps(metrics)},
                                              headers=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_single_metric(self, mock_requests):
        metrics = [{"timestamp": 123541423, "value": 0}]
        self.z.sendMetric('Zeus.Test', metrics)
        mock_requests.post.assert_called_with(FAKE_SERVER + '/metrics/' +
                                              FAKE_TOKEN + '/Zeus.Test/',
                                              data={"metrics":
                                                    json.dumps(metrics)},
                                              headers=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_single_metric_wrong_name(self, mock_requests):
        metrics = [{"timestamp": 123541423, "value": 0}]
        self.assertRaises(
            ZeusException, self.z.sendMetric, '_WrongName', metrics)
        self.assertRaises(
            ZeusException, self.z.sendMetric, 'W#?rongName', metrics)
        self.assertRaises(
            ZeusException, self.z.sendMetric, None, metrics)
        self.assertRaises(
            ZeusException, self.z.sendMetric, '', metrics)
        self.assertRaises(
            ZeusException, self.z.sendMetric, '0123456789ABCDEF' * 16,
            metrics)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_post_multiple_metrics(self, mock_requests):
        metrics = [{"timestamp": 123541423, "value": 0},
                   {"timestamp": 123541424, "value": 1},
                   {"timestamp": 123541425, "value": 2.0}, ]
        self.z.sendMetric('ZeusTest', metrics)
        mock_requests.post.assert_called_with(FAKE_SERVER + '/metrics/' +
                                              FAKE_TOKEN + '/ZeusTest/',
                                              data={"metrics":
                                                    json.dumps(metrics)},
                                              headers=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_metric_values(self, mock_requests):
        self.z.getMetric(metric_name='ZeusTest',
                         aggregator_function='sum',
                         aggregator_column='val1',
                         from_date=123456789,
                         to_date=126235344235,
                         group_interval='1m',
                         filter_condition='value > 90',
                         limit=10,
                         offset=20)
        mock_requests.get.assert_called_with(FAKE_SERVER + '/metrics/' +
                                             FAKE_TOKEN + '/_values/',
                                             params={'metric_name': 'ZeusTest',
                                                     'aggregator_function':
                                                     'sum',
                                                     'aggregator_column':
                                                     'val1',
                                                     'from': 123456789,
                                                     'to': 126235344235,
                                                     'group_interval': '1m',
                                                     'filter_condition':
                                                     'value > 90',
                                                     'limit': 10,
                                                     'offset': 20})

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_metric_names(self, mock_requests):
        self.z.getMetricNames(metric_name='ZeusTest',
                              limit=10,
                              offset=20)
        mock_requests.get.assert_called_with(FAKE_SERVER + '/metrics/' +
                                             FAKE_TOKEN + '/_names/',
                                             params={'metric_name': 'ZeusTest',
                                                     'limit': 10,
                                                     'offset': 20})

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_delete_metric(self, mock_requests):
        self.z.deleteMetric('ZeusTest')
        mock_requests.delete.assert_called_with(FAKE_SERVER + '/metrics/' +
                                                FAKE_TOKEN + '/ZeusTest/')

    @mock.patch('zeus.interfaces.rest.requests')
    def test_create_alert(self, mock_requests):

        alert_name = "testerino"
        username = "pelegrino"
        token = FAKE_TOKEN
        alerts_type = "metric"
        alert_expression = "cpu.value > 20"
        alert_severity = "S1"
        metric_name = "cpu.value"
        emails = "john1234@gmail.com"
        status = "active"
        notify_period = 60

        self.z.createAlert(alert_name, username, alerts_type,
                           alert_expression, alert_severity, metric_name,
                           emails, status, notify_period)
        data = {
            'alert_name': alert_name,
            'username': username,
            'token': token,
            'alerts_type': alerts_type,
            'alert_expression': alert_expression,
            'alert_severity': alert_severity,
            'metric_name': metric_name,
            'emails': emails,
            'status': status,
            'notify_period': notify_period
        }

        mock_requests.post.assert_called_with(
            FAKE_SERVER + '/alerts/' +
            FAKE_TOKEN, data=json.dumps(data),
            headers={'content-type': 'application/json'}
        )

    @mock.patch('zeus.interfaces.rest.requests')
    def test_modify_alert(self, mock_requests):

        alert_id = 42
        alert_name = "testerino"
        username = "pelegrino"
        token = FAKE_TOKEN
        alerts_type = "metric"
        alert_expression = "cpu.value > 20"
        alert_severity = "S1"
        metric_name = "cpu.value"
        emails = "john1234@gmail.com"
        status = "active"
        notify_period = 60

        self.z.modifyAlert(alert_id, alert_name, username, alerts_type,
                           alert_expression, alert_severity, metric_name,
                           emails, status, notify_period)
        data = {
            'alert_name': alert_name,
            'username': username,
            'token': token,
            'alerts_type': alerts_type,
            'alert_expression': alert_expression,
            'alert_severity': alert_severity,
            'metric_name': metric_name,
            'emails': emails,
            'status': status,
            'notify_period': notify_period
        }

        path = FAKE_SERVER + '/alerts/' + FAKE_TOKEN + '/' + str(alert_id)
        mock_requests.put.assert_called_with(
            path, data=json.dumps(data),
            headers={'content-type': 'application/json'}
        )

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_alerts(self, mock_requests):
        self.z.getAlerts()

        path = FAKE_SERVER + '/alerts/' + FAKE_TOKEN
        mock_requests.get.assert_called_with(path, params=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_alert(self, mock_requests):
        alert_id = 42
        self.z.getAlert(alert_id)

        path = FAKE_SERVER + '/alerts/' + FAKE_TOKEN + '/' + str(alert_id)
        mock_requests.get.assert_called_with(path, params=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_delete_alert(self, mock_requests):
        alert_id = 42
        self.z.deleteAlert(alert_id)

        path = FAKE_SERVER + '/alerts/' + FAKE_TOKEN + '/' + str(alert_id)
        mock_requests.delete.assert_called_with(path)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_enable_alerts(self, mock_requests):

        alert_id_list = [19, 42]
        self.z.enableAlerts(alert_id_list)
        data = {
            'id': alert_id_list
        }

        path = FAKE_SERVER + '/alerts/' + FAKE_TOKEN + '/enable'
        mock_requests.post.assert_called_with(
            path, data=json.dumps(data),
            headers={'content-type': 'application/json'}
        )

    @mock.patch('zeus.interfaces.rest.requests')
    def test_disable_alerts(self, mock_requests):

        alert_id_list = [19, 42]
        self.z.disableAlerts(alert_id_list)
        data = {
            'id': alert_id_list
        }

        path = FAKE_SERVER + '/alerts/' + FAKE_TOKEN + '/disable'
        mock_requests.post.assert_called_with(
            path, data=json.dumps(data),
            headers={'content-type': 'application/json'}
        )

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_triggered_alerts(self, mock_requests):

        self.z.getTriggeredAlerts()

        path = FAKE_SERVER + '/triggeredalerts/' + FAKE_TOKEN
        mock_requests.get.assert_called_with(path, params=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_triggered_alerts_last_24h(self, mock_requests):

        self.z.getTriggeredAlertsLast24Hours()

        path = FAKE_SERVER + '/triggeredalerts/' + FAKE_TOKEN + "/last24"
        mock_requests.get.assert_called_with(path, params=None)

    @mock.patch('zeus.interfaces.rest.requests')
    def test_get_delete_metric_wrong_name(self, mock_requests):
        self.assertRaises(
            ZeusException, self.z.deleteMetric, '_WrongName')

    @mock.patch('zeus.interfaces.rest.requests')
    def tearDown(self, mock_requests):
        pass


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-

# Copyright 2016 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class TrigAlertsInterface(object):

    def __init__(self, user_token, rest_client):
        self.token = user_token
        self.rest_client = rest_client

    def getTriggeredAlerts(self):

        """Return all triggered alerts

        :rtype: array
        """

        path = '/triggeredalerts/' + self.token
        return self.rest_client.sendGetRequest(path)

    def getTriggeredAlertsLast24Hours(self):

        """Return all triggered alerts in the last 24 hours

        :rtype: array
        """

        path = '/triggeredalerts/' + self.token + "/last24"
        return self.rest_client.sendGetRequest(path)



# -*- coding: utf-8 -*-

# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from interfaces.rest import RestClient
from interfaces.logs import LogsInterface
from interfaces.metrics import MetricsInterface
from interfaces.alerts import AlertsInterface
from interfaces.trigalerts import TrigAlertsInterface


class ZeusClient(MetricsInterface, LogsInterface, AlertsInterface,
                 TrigAlertsInterface):

    """Zeus Client class, implementing wrapper methods for the
    Zeus API.

    """

    def __init__(self, user_token, server):
        self.token = user_token
        rest_client = RestClient(server)
        self.server = rest_client.server
        super(ZeusClient, self).__init__(user_token, rest_client)



# -*- coding: utf-8 -*-

# Copyright 2016 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import requests
from urlparse import urlparse
from urlparse import urljoin

METHOD_POST = 'POST'
METHOD_GET = 'GET'
METHOD_PUT = 'PUT'
METHOD_DELETE = 'DELETE'


class RestClient(object):

    def __init__(self, server):
        # makes sure we always use https
        url_object = urlparse(server)
        url_parts = list(url_object)
        url_parts[0] = "https://"
        self.server = ''.join(url_parts)

    def _sendRequest(self, method, path, data=None, headers=None):
        final_url = urljoin(self.server, path)
        if method == METHOD_POST:
            r = requests.post(final_url, data=data, headers=headers)
        elif method == METHOD_GET:
            r = requests.get(final_url, params=data)
        elif method == METHOD_DELETE:
            r = requests.delete(final_url)
        elif method == METHOD_PUT:
            r = requests.put(final_url, data=data, headers=headers)

        if r.status_code == 500:
            raise Exception("Internal Server Error")
        try:
            return r.status_code, r.json()
        except Exception:
            return r.status_code

    def sendPostRequest(self, path, data=None, headers=None):
        return self._sendRequest(METHOD_POST, path, data, headers)

    def sendGetRequest(self, path, data=None, headers=None):
        return self._sendRequest(METHOD_GET, path, data, headers)

    def sendPutRequest(self, path, data=None, headers=None):
        return self._sendRequest(METHOD_PUT, path, data, headers)

    def sendDeleteRequest(self, path, data=None, headers=None):
        return self._sendRequest(METHOD_DELETE, path, data, headers)



# -*- coding: utf-8 -*-

# Copyright 2016 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import re


def validateMetricName(name):
    if name is None:
        raise ZeusException("Invalid input. Metric name cannot be None.")
    name_length = len(name)
    if name_length < 1 or name_length > 255:
        raise ZeusException("Invalid metric name. It must be longer than "
                            "1 character and shorter than 255 charaters.")
    if not re.match(r"^[^_.-][.\w-]*$", name):
        raise ZeusException("Invalid metric name. The name needs to start "
                            "with a letter or number and can contain "
                            "_ - or .")


def validateDates(from_date, to_date):
    try:
        from_date_value = float(from_date) if from_date else None
        to_date_value = float(to_date) if to_date else None
    except ValueError as e:
        raise ZeusException("Invalid date. %s" % str(e))
    if (from_date_value is None) or (to_date_value is None):
        return
    elif from_date_value > to_date_value:
        raise ZeusException("Invalid date. The from_date should not be "
                            "after to_date.")


def validateLogName(name):
    if name is None:
        raise ZeusException("Invalid input. Log name cannot be None.")
    name_length = len(name)
    if name_length < 1 or name_length > 255:
        raise ZeusException("Invalid log name. It must be longer than 1 "
                            "character and shorter than 255 charaters.")
    if not re.match(r"^[a-zA-Z0-9]*$", name):
        raise ZeusException("Invalid log name. It can only contain "
                            "letters or numbers.")


class ZeusException(Exception):
    pass



# -*- coding: utf-8 -*-

# Copyright 2016 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
from utils import validateMetricName, validateDates


class MetricsInterface(object):

    def __init__(self, user_token, rest_client):
        self.token = user_token
        self.rest_client = rest_client

    def sendMetric(self, metric_name, metrics):
        """Return ``dict`` saying how many *metrics* were successfully inserted
        with *metric_name*.

        :param string metric_name: String with the name of the metric.
        :param dict metrics: ``array`` of ``dict`` containing the metrics to
         send.
        :rtype: dict

        """
        validateMetricName(metric_name)
        data = {'metrics': json.dumps(metrics)}
        return self.rest_client.sendPostRequest('/metrics/' + self.token +
                                                '/' + metric_name + '/', data)

    def getMetric(self, metric_name,
                  from_date=None,
                  to_date=None,
                  aggregator_function=None,
                  aggregator_column=None,
                  group_interval=None,
                  filter_condition=None,
                  offset=None,
                  limit=None):
        """Return ``array`` of ``dict`` with the metrics that match the params.

        :param string metric_name: Name of the metric.
        :param string from_date: Unix formatted start date.
        :param string to_date: Unix formatted end date.
        :param string aggregator_function: Aggregator function. ``sum``,
        ``count``, ``min``, ``max``,...
        :param string aggregator_column: Column to which
        ``aggregator_function`` is to be applied.
        :param string group_interval: Intervals in which to group the results.
        :param string filter_condition: Filters to be applied to metric values.
        :param string offset: Result offset.
        :param string limit: Max number of results in the return.
        :rtype: array

        """
        validateDates(from_date, to_date)
        data = {"metric_name": metric_name}
        if from_date:
            data['from'] = from_date
        if to_date:
            data['to'] = to_date
        if aggregator_function:
            # EG. 'sum'
            data['aggregator_function'] = aggregator_function
        if aggregator_column:
            # EG. 'sum'
            data['aggregator_column'] = aggregator_column
        if group_interval:
            # EG. '1m'
            data['group_interval'] = group_interval
        if filter_condition:
            # EG. '"Values" < 33'
            data['filter_condition'] = filter_condition
        if limit:
            data['limit'] = limit
        if offset:
            data['offset'] = offset

        return self.rest_client.sendGetRequest('/metrics/' + self.token +
                                               '/_values/', data)

    def getMetricNames(self, metric_name=None, limit=None, offset=None):
        """Return ``array`` of ``string`` with the metric names that match the
        params.

        :param string metric_name: Pattern for the metric name.
        :param string limit: Max number of results in the return.
        :param string limit: Starting offset in the resulting list. The default
        value is 0 (first result).
        :rtype: array

        """
        data = {}
        if metric_name:
            data['metric_name'] = metric_name
        if limit:
            data['limit'] = limit
        if offset:
            data['offset'] = offset

        return self.rest_client.sendGetRequest('/metrics/' + self.token +
                                               '/_names/', data)

    def deleteMetric(self, metric_name):
        """Delete an entire metric from Zeus.

        :param string metric_name: Pattern for the metric name.
        :rtype: boolean

        """
        validateMetricName(metric_name)
        return self.rest_client.sendDeleteRequest(
            '/metrics/' + self.token + '/' + metric_name + '/', None
        )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

with open('test_requirements.txt') as f:
    test_requirements = f.read().splitlines()

setup(
    name='cisco-zeus',
    version='0.2.2.6',
    description="Python client for CiscoZeus.io. It allows a user to post/query logs and metrics using Zeus.",
    long_description=readme + '\n\n' + history,
    author="Marc Solanas Tarre",
    author_email='msolanas@cisco.com',
    url='https://github.com/CiscoZeus/python-zeusclient.git',
    packages=[
        'zeus',
        'zeus.interfaces',
    ],
    package_dir={
        'zeus': 'zeus',
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache License 2.0",
    zip_safe=False,
    keywords='zeus',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
